@@ -26,10 +26,6 @@ var (
 	client = common.SaneHttpClient()
 )
 
-type proxyRes struct {
-	Verified bool `json:"verified"`
-}
-
 // Keywords are used for efficiently pre-filtering chunks.
 // Use identifiers in the secret preferably, or the provider name.
 func (s Scanner) Keywords() []string {
